==> reveal.js-plugins-4.2.2.tgz: package/README.md <==
# Reveal.js-plugins

This is a collection of plugins for [Reveal.js](https://revealjs.com) - a framework for easily creating beautiful presentations using HTML.

This collections includes the following plugins:

- [Animate](https://github.com/rajgoel/reveal.js-plugins/tree/master/animate): A plugin for animations using SVG.js.
- [Anything](https://github.com/rajgoel/reveal.js-plugins/tree/master/anything): A plugin for adding plots, charts, animated SVGs,or anything else inside an HTML object using a JSON string and a javascript function.
- [Audio slideshow](https://github.com/rajgoel/reveal.js-plugins/tree/master/audio-slideshow): A plugin for audio playback and recording.
- [Chalkboard](https://github.com/rajgoel/reveal.js-plugins/tree/master/chalkboard): A plugin adding a chalkboard and slide annotation.
- [Chart](https://github.com/rajgoel/reveal.js-plugins/tree/master/chart):  A plugin for using Chart.js.
- [Custom controls](https://github.com/rajgoel/reveal.js-plugins/tree/master/customcontrols):  A plugin for customization of controls.
- [Fullscreen](https://github.com/rajgoel/reveal.js-plugins/tree/master/fullscreen):  A simple plugin allowing to use fullscreen slides.
 - [Load content](https://github.com/rajgoel/reveal.js-plugins/tree/master/loadcontent): A plugin allowing to load external content into the body of HTML-elements.
- [Seminar](https://github.com/rajgoel/reveal.js-plugins/tree/master/seminar): a plugin providing interaction capabilities with other hosts and participants (e.g. slide events, chalkboard drawings, Q&A, polls).
- [Poll](https://github.com/rajgoel/reveal.js-plugins/tree/master/poll): a plugin providing online polls (based on the `seminar` plugin).
- [Questions](https://github.com/rajgoel/reveal.js-plugins/tree/master/questions): a plugin adding Q&As to slide decks (based on the `seminar` plugin).

## Demos

Demos for the plugin collection can be found here: <https://rajgoel.github.io/reveal.js-demos/>.

## Getting started

The easiest to get started is to take start with [minimal.html](minimal.html) and a look at the documentation of each of the plugins. The source code of the demos gives further examples and can be found here: <https://github.com/rajgoel/reveal.js-demos>.


## License

MIT licensed

Copyright (C) 2023 Asvin Goel

==> reveal.js-plugins-4.2.5.tgz: package/README.md <==
# Reveal.js-plugins

This is a collection of plugins for [Reveal.js](https://revealjs.com) - a framework for easily creating beautiful presentations using HTML.

This collections includes the following plugins:

- [Animate](https://github.com/rajgoel/reveal.js-plugins/tree/master/animate): A plugin for animations using SVG.js.
- [Anything](https://github.com/rajgoel/reveal.js-plugins/tree/master/anything): A plugin for adding plots, charts, animated SVGs,or anything else inside an HTML object using a JSON string and a javascript function.
- [Audio slideshow](https://github.com/rajgoel/reveal.js-plugins/tree/master/audio-slideshow): A plugin for audio playback and recording.
- [Chalkboard](https://github.com/rajgoel/reveal.js-plugins/tree/master/chalkboard): A plugin adding a chalkboard and slide annotation.
- [Chart](https://github.com/rajgoel/reveal.js-plugins/tree/master/chart):  A plugin for using Chart.js.
- [Custom controls](https://github.com/rajgoel/reveal.js-plugins/tree/master/customcontrols):  A plugin for customization of controls.
- [Fullscreen](https://github.com/rajgoel/reveal.js-plugins/tree/master/fullscreen):  A simple plugin allowing to use fullscreen slides.
 - [Load content](https://github.com/rajgoel/reveal.js-plugins/tree/master/loadcontent): A plugin allowing to load external content into the body of HTML-elements.
- [Seminar](https://github.com/rajgoel/reveal.js-plugins/tree/master/seminar): a plugin providing interaction capabilities with other hosts and participants (e.g. slide events, chalkboard drawings, Q&A, polls).
- [Poll](https://github.com/rajgoel/reveal.js-plugins/tree/master/poll): a plugin providing online polls (based on the `seminar` plugin).
- [Questions](https://github.com/rajgoel/reveal.js-plugins/tree/master/questions): a plugin adding Q&As to slide decks (based on the `seminar` plugin).

## Demos

Demos for the plugin collection can be found here: <https://rajgoel.github.io/reveal.js-demos/>.

## Getting started

The easiest to get started is to start with [minimal.html](minimal.html) and take a look at the documentation of each of the plugins. The source code of the demos gives further examples and can be found here: <https://github.com/rajgoel/reveal.js-demos>.


## License

MIT licensed

Copyright (C) 2023 Asvin Goel
